import _toConsumableArray from '@babel/runtime/helpers/toConsumableArray';
import _defineProperty from '@babel/runtime/helpers/defineProperty';
import _slicedToArray from '@babel/runtime/helpers/slicedToArray';
import React__default, { useState, useMemo, useRef } from 'react';
import _ from 'lodash';
import Popover from '../Popover/index.js';
import { FilterPanel } from '../Grid/FilterPanel.js';
import SvgAddFilterIcon from '../../assets/svgs/add-filter-icon.svg.js';
import SvgCloseIcon from '../../assets/svgs/close-icon.svg.js';
import SvgTriangle from '../../assets/svgs/triangle.svg.js';
import './ExternalTableFilters.scss.js';
import ButtonBase from '../ButtonBase/index.js';
import useEvent from '../../hooks/useEvent.js';

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); enumerableOnly && (symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; })), keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = null != arguments[i] ? arguments[i] : {}; i % 2 ? ownKeys(Object(source), !0).forEach(function (key) { _defineProperty(target, key, source[key]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)) : ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } return target; }

var ExternalColumnFilterButton = function ExternalColumnFilterButton(_ref) {
  var columnId = _ref.columnId,
      label = _ref.label,
      columnFilterOptions = _ref.columnFilterOptions,
      _ref$columnFilterStat = _ref.columnFilterState,
      columnFilterState = _ref$columnFilterStat === void 0 ? {
    activeCount: 0
  } : _ref$columnFilterStat,
      setColumnFilterInvisible = _ref.setColumnFilterInvisible,
      _updateColumnFilter = _ref.updateColumnFilter;

  var _useState = useState(columnFilterState.activeCount === 0),
      _useState2 = _slicedToArray(_useState, 2),
      isOpen = _useState2[0],
      setIsOpen = _useState2[1];

  var count = columnFilterState.activeCount;
  var caretStyle = isOpen ? {
    transform: 'scaleY(-1)'
  } : undefined;
  var ref = useRef();
  useEvent('click', function (e) {
    var _ref$current;

    if (!(ref !== null && ref !== void 0 && (_ref$current = ref.current) !== null && _ref$current !== void 0 && _ref$current.contains(e.target))) {
      setIsOpen(false);
    }
  }, true);
  var column = {
    filterOptions: columnFilterOptions,
    filterState: columnFilterState,
    updateColumnFilter: function updateColumnFilter(e) {
      _updateColumnFilter(e);

      setIsOpen(false);
    }
  };
  return /*#__PURE__*/React__default.createElement("div", {
    className: "Suc-external-column-filter-button",
    ref: ref
  }, /*#__PURE__*/React__default.createElement("div", {
    className: "Suc-extrenal-filter-first-line ".concat(isOpen ? 'open' : '')
  }, /*#__PURE__*/React__default.createElement("div", {
    className: "Suc-filter-label",
    onClick: function onClick() {
      return setIsOpen(!isOpen);
    }
  }, label, count > 0 && " (".concat(count, ")")), /*#__PURE__*/React__default.createElement("div", {
    className: "Suc-filter-actions"
  }, /*#__PURE__*/React__default.createElement(ButtonBase, {
    onClick: function onClick() {
      return setIsOpen(!isOpen);
    },
    className: "Suc-filter-caret"
  }, /*#__PURE__*/React__default.createElement(SvgTriangle, {
    style: caretStyle
  })), /*#__PURE__*/React__default.createElement("div", {
    className: "Suc-filter-pipe"
  }, "|"), /*#__PURE__*/React__default.createElement(ButtonBase, {
    className: "Suc-filter-close",
    onClick: function onClick() {
      setColumnFilterInvisible(columnId);

      _updateColumnFilter({});
    }
  }, /*#__PURE__*/React__default.createElement(SvgCloseIcon, null)))), isOpen && /*#__PURE__*/React__default.createElement(FilterPanel, {
    column: column,
    setIsOpen: setIsOpen
  }));
};

var AddFilterPopover = function AddFilterPopover(_ref2) {
  var unfilteredColumns = _ref2.unfilteredColumns,
      setColumnFilterVisible = _ref2.setColumnFilterVisible;

  var _useState3 = useState(false),
      _useState4 = _slicedToArray(_useState3, 2),
      isOpen = _useState4[0],
      setIsOpen = _useState4[1];

  var close = function close() {
    return setIsOpen(false);
  };

  return /*#__PURE__*/React__default.createElement(Popover, {
    trigger: 'click',
    appendToBody: true,
    container: /*#__PURE__*/React__default.createElement(SvgAddFilterIcon, null),
    visible: isOpen,
    onVisibleChange: setIsOpen
  }, /*#__PURE__*/React__default.createElement("div", {
    className: "Suc-select-columns-popover"
  }, unfilteredColumns.map(function (_ref3) {
    var id = _ref3.id,
        Header = _ref3.Header;
    return /*#__PURE__*/React__default.createElement(ButtonBase, {
      key: id,
      onClick: function onClick() {
        setColumnFilterVisible(id);
        close();
      }
    }, Header);
  })));
};

var ExternalTableFilters = function ExternalTableFilters(_ref4) {
  var filterState = _ref4.filterState,
      updateFilterState = _ref4.updateFilterState,
      columns = _ref4.columns,
      resetFilters = _ref4.resetFilters;

  var _useState5 = useState(Object.keys(filterState.columns)),
      _useState6 = _slicedToArray(_useState5, 2),
      visibleFilters = _useState6[0],
      setVisibleFilters = _useState6[1];

  var columnsMap = _.keyBy(columns, 'id');

  var filterOptions = useMemo(function () {
    return columns.reduce(function (acc, col) {
      if (col.filterOptions) {
        return _objectSpread(_objectSpread({}, acc), {}, _defineProperty({}, col.id, col.filterOptions));
      } else return acc;
    }, {});
  }, [columns]);

  var setColumnFilterVisible = function setColumnFilterVisible(id) {
    setVisibleFilters([].concat(_toConsumableArray(visibleFilters), [id]));
  };

  var setColumnFilterInvisible = function setColumnFilterInvisible(id) {
    setVisibleFilters(visibleFilters.filter(function (fId) {
      return fId !== id;
    }));
  };

  var clearAll = function clearAll() {
    resetFilters();
    setVisibleFilters([]);
  };

  var unfilteredColumns = useMemo(function () {
    return _.filter(columns, function (col) {
      return filterOptions[col.id] && !visibleFilters.find(function (f) {
        return f === col.id;
      });
    });
  }, [filterOptions, visibleFilters]);
  return /*#__PURE__*/React__default.createElement("div", {
    className: "Suc-external-column-filters"
  }, /*#__PURE__*/React__default.createElement("div", {
    className: "Suc-external-filters-label"
  }, "Filter By"), /*#__PURE__*/React__default.createElement("div", {
    className: "Suc-external-filters-group"
  }, visibleFilters.map(function (columnId) {
    var updateColumnFilter = function updateColumnFilter(values) {
      updateFilterState({
        id: columnId,
        values: values
      });
    };

    return /*#__PURE__*/React__default.createElement(ExternalColumnFilterButton, {
      key: columnId,
      label: columnsMap[columnId].Header,
      columnFilterState: filterState.columns[columnId],
      columnFilterOptions: filterOptions[columnId],
      filterConfig: columnsMap[columnId].filter,
      columnId: columnId,
      setColumnFilterInvisible: setColumnFilterInvisible,
      updateColumnFilter: updateColumnFilter
    });
  })), /*#__PURE__*/React__default.createElement("div", {
    className: "Suc-add-extrenal-filter ".concat(unfilteredColumns.length === 0 ? 'disabled' : '')
  }, /*#__PURE__*/React__default.createElement(AddFilterPopover, {
    setColumnFilterVisible: setColumnFilterVisible,
    unfilteredColumns: unfilteredColumns
  })), (filterState === null || filterState === void 0 ? void 0 : filterState.count) > 0 && /*#__PURE__*/React__default.createElement(ButtonBase, {
    className: "Suc-external-filters-clear-all",
    onClick: clearAll
  }, "Clear All"));
};

export { ExternalTableFilters as default };
//# sourceMappingURL=index.js.map
